@@ -22,6 +22,9 @@
 #define AKONADI_CALENDARMODEL_P_H
 
 #include <akonadi/entitytreemodel.h>
+#include <QSharedPointer>
+#include <QWeakPointer>
+
 
 namespace Akonadi {
 
@@ -29,6 +32,7 @@ class CalendarModel : public Akonadi::EntityTreeModel
 {
     Q_OBJECT
 public:
+    typedef QSharedPointer<CalendarModel> Ptr;
     enum ItemColumn {
         Summary=0,
         Type,
@@ -50,9 +54,12 @@ public:
         RecursRole
     };
 
-    explicit CalendarModel(Akonadi::ChangeRecorder *monitor, QObject *parent = 0);
+    static Akonadi::CalendarModel::Ptr create(Akonadi::ChangeRecorder *monitor);
     ~CalendarModel();
 
+    QWeakPointer<CalendarModel> weakPointer() const;
+    void setWeakPointer(const QWeakPointer<CalendarModel> &weakPointer);
+
     /* reimp */
     QVariant entityData(const Akonadi::Item &item, int column, int role=Qt::DisplayRole) const;
 
@@ -68,6 +75,7 @@ public:
                               EntityTreeModel::HeaderGroup headerSet) const;
 
 private:
+    explicit CalendarModel(Akonadi::ChangeRecorder *monitor);
     class Private;
     Private *const d;
 };
