@@ -33,7 +33,7 @@
 #include <kcalcore/journal.h>
 
 #include <KJob>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KDebug>
 #include <KDateTime>
 #include <KUrl>
@@ -43,7 +43,6 @@
 
 #include <QUrl>
 #include <QFile>
-#include <QMetaObject>
 #include <QDBusInterface>
 
 using namespace KCalCore;
