@@ -31,42 +31,41 @@
 #include <QtDBus/QDBusConnectionInterface>
 #include <QtDBus/QDBusInterface>
 #include <QtDBus/QDBusReply>
-#include <QDebug>
 
 #include <unistd.h>
 
 static bool isEkigaServiceRegistered()
 {
-    const QLatin1String service( "org.ekiga.Ekiga" );
+    const QLatin1String service("org.ekiga.Ekiga");
 
-    QDBusConnectionInterface *interface = QDBusConnection::systemBus().interface();
-    if ( interface->isServiceRegistered( service ) ) {
+    QDBusConnectionInterface *interface = QDBusConnection::sessionBus().interface();
+    if (interface->isServiceRegistered(service)) {
         return true;
     }
 
     interface = Akonadi::DBusConnectionPool::threadConnection().interface();
-    if ( interface->isServiceRegistered( service ) ) {
+    if (interface->isServiceRegistered(service)) {
         return true;
     }
     return false;
 }
 
-static QDBusInterface* searchEkigaDBusInterface()
+static QDBusInterface *searchEkigaDBusInterface()
 {
-  const QLatin1String service( "org.ekiga.Ekiga" );
-  const QLatin1String path( "/org/ekiga/Ekiga" );
+    const QLatin1String service("org.ekiga.Ekiga");
+    const QLatin1String path("/org/ekiga/Ekiga");
 
-  QDBusInterface *interface = new QDBusInterface( service, path, QString(), QDBusConnection::systemBus() );
-  if ( !interface->isValid() ) {
-    delete interface;
-    interface = new QDBusInterface( service, path, QString(), Akonadi::DBusConnectionPool::threadConnection() );
-  }
+    QDBusInterface *interface = new QDBusInterface(service, path, QString(), QDBusConnection::sessionBus());
+    if (!interface->isValid()) {
+        delete interface;
+        interface = new QDBusInterface(service, path, QString(), Akonadi::DBusConnectionPool::threadConnection());
+    }
 
-  return interface;
+    return interface;
 }
 
-QEkigaDialer::QEkigaDialer( const QString &applicationName )
-    : QDialer( applicationName ), mInterface( 0 )
+QEkigaDialer::QEkigaDialer(const QString &applicationName)
+    : QDialer(applicationName), mInterface(0)
 {
 }
 
@@ -78,18 +77,18 @@ QEkigaDialer::~QEkigaDialer()
 bool QEkigaDialer::initializeEkiga()
 {
     // first check whether dbus interface is available yet
-    if ( !isEkigaServiceRegistered() ) {
+    if (!isEkigaServiceRegistered()) {
 
         // it could be skype is not running yet, so start it now
-        if ( !QProcess::startDetached( QLatin1String( "ekiga" ), QStringList() ) ) {
-            mErrorMessage = i18n( "Unable to start ekiga process, check that ekiga executable is in your PATH variable." );
+        if (!QProcess::startDetached(QLatin1String("ekiga"), QStringList())) {
+            mErrorMessage = i18n("Unable to start ekiga process, check that ekiga executable is in your PATH variable.");
             return false;
         }
 
         const int runs = 100;
-        for ( int i = 0; i < runs; ++i ) {
-            if ( !isEkigaServiceRegistered() ) {
-                ::sleep( 2 );
+        for (int i = 0; i < runs; ++i) {
+            if (!isEkigaServiceRegistered()) {
+                ::sleep(2);
             } else {
                 break;
             }
@@ -99,12 +98,12 @@ bool QEkigaDialer::initializeEkiga()
     // check again for the dbus interface
     mInterface = searchEkigaDBusInterface();
 
-    if ( !mInterface->isValid() ) {
-      delete mInterface;
-      mInterface = 0;
+    if (!mInterface->isValid()) {
+        delete mInterface;
+        mInterface = 0;
 
-      mErrorMessage = i18n( "Ekiga Public API (D-Bus) seems to be disabled." );
-      return false;
+        mErrorMessage = i18n("Ekiga Public API (D-Bus) seems to be disabled.");
+        return false;
     }
 
     return true;
@@ -112,15 +111,18 @@ bool QEkigaDialer::initializeEkiga()
 
 bool QEkigaDialer::dialNumber(const QString &number)
 {
-    if ( !initializeEkiga() ) {
+    if (!initializeEkiga()) {
         return false;
     }
-    QDBusReply<void> reply = mInterface->call( QLatin1String( "Call" ), number );
+    QDBusReply<void> reply = mInterface->call(QLatin1String("Call"), number);
     return true;
 }
 
-bool QEkigaDialer::sendSms(const QString &, const QString &)
+bool QEkigaDialer::sendSms(const QString &number, const QString &text)
 {
-    mErrorMessage = i18n( "Sending an SMS is currently not supported on Ekiga" );
+    Q_UNUSED(number);
+    Q_UNUSED(text);
+    mErrorMessage = i18n("Sending an SMS is currently not supported on Ekiga.");
     return false;
 }
+
