@@ -46,7 +46,7 @@ class CollectionFilterModel : public QSortFilterProxyModel
      *
      * @param parent The parent object.
      */
-    CollectionFilterModel( QObject *parent );
+    explicit CollectionFilterModel( QObject *parent );
 
     /**
      * Adds a mime type to the content mime type filter list.
@@ -54,6 +54,8 @@ class CollectionFilterModel : public QSortFilterProxyModel
      * If a mime type has been added, only collections that contain
      * this mime type in their content mime types will be listed by
      * this proxy model.
+     *
+     * @param mimeType mime type content filter
      */
     void addContentMimeTypeFilter( const QString &mimeType );
 
@@ -62,6 +64,8 @@ class CollectionFilterModel : public QSortFilterProxyModel
      *
      * Only collections that allows this rights combination
      * will be listed by this proxy model.
+     *
+     * @param rights collection rights filter
      */
     void setRightsFilter( Akonadi::Collection::Rights rights );
 
