@@ -42,14 +42,12 @@
 #include <KColorScheme>
 
 #include <QtCore/QTimer>
-#include <QGridLayout>
 #include <QMessageBox>
-#include <QTableView>
 
 using namespace Akonadi;
 
 ContactGroupEditor::Private::Private( ContactGroupEditor *parent )
-  : mParent( parent ), mMonitor( 0 ), mReadOnly( false )
+  : mParent( parent ), mMonitor( 0 ), mReadOnly( false ), mGroupModel( 0 )
 {
 }
 
