@@ -81,8 +81,8 @@ class SearchLineEdit : public KLineEdit
 class EmailAddressSelectionWidget::Private
 {
   public:
-    Private( EmailAddressSelectionWidget *qq, QAbstractItemModel *model )
-      : q( qq ), mModel( model )
+    Private( bool showOnlyContactWithEmail, EmailAddressSelectionWidget *qq, QAbstractItemModel *model )
+      : q( qq ), mModel( model ), mShowOnlyContactWithEmail(showOnlyContactWithEmail)
     {
       init();
     }
@@ -95,6 +95,7 @@ class EmailAddressSelectionWidget::Private
     SearchLineEdit *mSearchLine;
     Akonadi::EntityTreeView *mView;
     EmailAddressSelectionProxyModel *mSelectionModel;
+    bool mShowOnlyContactWithEmail;
 };
 
 void EmailAddressSelectionWidget::Private::init()
@@ -146,7 +147,8 @@ void EmailAddressSelectionWidget::Private::init()
   layout->addWidget( mView );
 
   Akonadi::ContactsFilterProxyModel *filter = new Akonadi::ContactsFilterProxyModel( q );
-  filter->setFilterFlags( ContactsFilterProxyModel::HasEmail );
+  if (mShowOnlyContactWithEmail)
+      filter->setFilterFlags( ContactsFilterProxyModel::HasEmail );
   filter->setExcludeVirtualCollections( true );
   filter->setSourceModel( mModel );
 
@@ -170,13 +172,19 @@ void EmailAddressSelectionWidget::Private::init()
 
 EmailAddressSelectionWidget::EmailAddressSelectionWidget( QWidget * parent )
   : QWidget( parent ),
-    d( new Private( this, 0 ) )
+    d( new Private( true, this, 0 ) )
 {
 }
 
 EmailAddressSelectionWidget::EmailAddressSelectionWidget( QAbstractItemModel *model, QWidget * parent )
   : QWidget( parent ),
-    d( new Private( this, model ) )
+    d( new Private( true, this, model ) )
+{
+}
+
+EmailAddressSelectionWidget::EmailAddressSelectionWidget( bool showOnlyContactWithEmail, QAbstractItemModel *model, QWidget * parent )
+  : QWidget( parent ),
+    d( new Private( showOnlyContactWithEmail ,this, model ) )
 {
 }
 
@@ -200,8 +208,12 @@ EmailAddressSelection::List EmailAddressSelectionWidget::selectedAddresses() con
     selection.d->mEmailAddress = index.data( EmailAddressSelectionProxyModel::EmailAddressRole ).toString();
     selection.d->mItem = index.data( ContactsTreeModel::ItemRole ).value<Akonadi::Item>();
 
-    if ( !selection.d->mEmailAddress.isEmpty() ) {
-      selections << selection;
+    if ( d->mShowOnlyContactWithEmail ) {
+        if ( !selection.d->mEmailAddress.isEmpty() ) {
+            selections << selection;
+        }
+    } else {
+        selections << selection;
     }
   }
 
