@@ -25,8 +25,6 @@
 #include <QtCore/QPointer>
 #include <QWidget>
 
-class QLabel;
-class QProgressBar;
 class KJob;
 
 /**
@@ -38,8 +36,8 @@ class WaitingOverlay : public QWidget
   public:
     /**
      * Create an overlay widget on @p baseWidget for @p job.
-     * @p baseWidget must not be null.
-     * @p parent must not be equal to @p baseWidget
+     * @param baseWidget must not be null.
+     * @param parent must not be equal to baseWidget
      */
     explicit WaitingOverlay( KJob *job, QWidget *baseWidget, QWidget *parent = 0 );
     ~WaitingOverlay();
@@ -52,7 +50,6 @@ class WaitingOverlay : public QWidget
 
   private:
     QPointer<QWidget> mBaseWidget;
-    QLabel *mDescription;
     bool mPreviousState;
 };
 
