@@ -74,7 +74,8 @@ QString EntityDeletedAttribute::restoreResource() const
 
 QByteArray Akonadi::EntityDeletedAttribute::type() const
 {
-    return "DELETED";
+    static const QByteArray sType( "DELETED" );
+    return sType;
 }
 
 EntityDeletedAttribute *EntityDeletedAttribute::clone() const
