@@ -28,48 +28,61 @@
 
 using namespace Akonadi;
 
-class Akonadi::ItemMoveJobPrivate: public MoveJobImpl<Item, ItemMoveJob>
+class Akonadi::ItemMoveJobPrivate : public MoveJobImpl<Item, ItemMoveJob>
 {
-  public:
-    ItemMoveJobPrivate( ItemMoveJob *parent ) : MoveJobImpl<Item, ItemMoveJob>( parent ) {}
-    Q_DECLARE_PUBLIC( ItemMoveJob )
+public:
+    ItemMoveJobPrivate(ItemMoveJob *parent)
+        : MoveJobImpl<Item, ItemMoveJob>(parent)
+    {
+    }
+    Q_DECLARE_PUBLIC(ItemMoveJob)
 };
 
-ItemMoveJob::ItemMoveJob(const Item &item, const Collection &destination, QObject *parent) :
-    Job( new ItemMoveJobPrivate( this ), parent )
+ItemMoveJob::ItemMoveJob(const Item &item, const Collection &destination, QObject *parent)
+    : Job(new ItemMoveJobPrivate(this), parent)
 {
-  Q_D( ItemMoveJob );
-  d->destination = destination;
-  d->objectsToMove.append( item );
+    Q_D(ItemMoveJob);
+    d->destination = destination;
+    d->objectsToMove.append(item);
 }
 
-ItemMoveJob::ItemMoveJob( const Item::List &items, const Collection &destination, QObject* parent) :
-  Job( new ItemMoveJobPrivate( this ), parent )
+ItemMoveJob::ItemMoveJob(const Item::List &items, const Collection &destination, QObject *parent)
+    : Job(new ItemMoveJobPrivate(this), parent)
 {
-  Q_D( ItemMoveJob );
-  d->destination = destination;
-  d->objectsToMove = items;
+    Q_D(ItemMoveJob);
+    d->destination = destination;
+    d->objectsToMove = items;
 }
 
+ItemMoveJob::ItemMoveJob(const Item::List &items, const Collection &source, const Collection &destination, QObject *parent)
+  : Job(new ItemMoveJobPrivate(this), parent)
+{
+    Q_D(ItemMoveJob);
+    d->source = source;
+    d->destination = destination;
+    d->objectsToMove = items;
+}
+
+
 ItemMoveJob::~ItemMoveJob()
 {
 }
 
 void ItemMoveJob::doStart()
 {
-  Q_D( ItemMoveJob );
-  d->sendCommand( "MOVE" );
+    Q_D(ItemMoveJob);
+    d->sendCommand("MOVE");
 }
 
 Collection ItemMoveJob::destinationCollection() const
 {
-  Q_D( const ItemMoveJob );
-  return d->destination;
+    Q_D(const ItemMoveJob);
+    return d->destination;
 }
 
 QList<Item> ItemMoveJob::items() const
 {
-  Q_D( const ItemMoveJob );
-  return d->objectsToMove;
+    Q_D(const ItemMoveJob);
+    return d->objectsToMove;
 }
 
