@@ -25,8 +25,9 @@
 
 #include <QtCore/QDebug>
 #include <QtCore/QFile>
-#include <QtGui/QApplication>
+#include <QApplication>
 
+#include <klocale.h>
 #include <kapplication.h>
 #include <kcmdlineargs.h>
 
@@ -101,4 +102,3 @@ int main( int argc, char** argv )
   return app.exec();
 }
 
-#include "itemdumper.moc"
