@@ -271,6 +271,11 @@ Collection::List XmlDocument::collections() const
   return XmlReader::readCollections( d->document.documentElement() );
 }
 
+Tag::List XmlDocument::tags() const
+{
+  return XmlReader::readTags( d->document.documentElement() );
+}
+
 Collection::List XmlDocument::childCollections(const QString& parentCollectionRid) const
 {
   Collection c;
