@@ -24,7 +24,7 @@
 #include "addresseedialog.h"
 
 #include <kinputdialog.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kdebug.h>
 #include <kmessagebox.h>
 #include <kcombobox.h>
