@@ -74,6 +74,47 @@ static void ldif_out( QTextStream &t, const QString &formatStr,
   t << QString::fromUtf8( txt ) << "\n";
 }
 
+bool LDIFConverter::addresseeAndContactGroupToLDIF( const AddresseeList &addrList, const ContactGroup::List &contactGroupList, QString &str )
+{
+    bool result = addresseeToLDIF( addrList, str );
+    if (!contactGroupList.isEmpty()) {
+        result = contactGroupToLDIF( contactGroupList, str );
+    }
+    return result;
+}
+
+bool LDIFConverter::contactGroupToLDIF( const ContactGroup &contactGroup, QString &str )
+{
+    if ( contactGroup.dataCount() <= 0 ) {
+        return false;
+    }
+    QTextStream t( &str, QIODevice::WriteOnly|QIODevice::Append );
+    t.setCodec( QTextCodec::codecForName( "UTF-8" ) );
+    t << "objectclass: top\n";
+    t << "objectclass: groupOfNames\n";
+
+    for (unsigned int i = 0; i < contactGroup.dataCount(); ++i) {
+        ContactGroup::Data data = contactGroup.data(i);
+        const QString value = QString::fromLatin1("cn=%1,mail=%2").arg(data.name()).arg(data.email());
+        ldif_out( t, QLatin1String( "member" ), value );
+    }
+
+    t << "\n";
+    return true;
+}
+
+bool LDIFConverter::contactGroupToLDIF( const ContactGroup::List &contactGroupList, QString &str )
+{
+    ContactGroup::List::ConstIterator it;
+    ContactGroup::List::ConstIterator end( contactGroupList.constEnd() );
+    for ( it = contactGroupList.constBegin(); it != end; ++it ) {
+      contactGroupToLDIF( *it, str );
+    }
+    return true;
+}
+
+
+
 bool LDIFConverter::addresseeToLDIF( const Addressee &addr, QString &str )
 {
   if ( addr.isEmpty() ) {
@@ -89,6 +130,12 @@ bool LDIFConverter::addresseeToLDIF( const Addressee &addr, QString &str )
   ldif_out( t, QLatin1String( "dn" ), QString::fromLatin1( "cn=%1,mail=%2" ).
             arg( addr.formattedName().simplified() ).
             arg( addr.preferredEmail() ) );
+
+  t << "objectclass: top\n";
+  t << "objectclass: person\n";
+  t << "objectclass: organizationalPerson\n";
+
+
   ldif_out( t, QLatin1String( "givenname" ), addr.givenName() );
   ldif_out( t, QLatin1String( "sn" ), addr.familyName() );
   ldif_out( t, QLatin1String( "cn" ), addr.formattedName().simplified() );
@@ -98,8 +145,14 @@ bool LDIFConverter::addresseeToLDIF( const Addressee &addr, QString &str )
   ldif_out( t, QLatin1String( "mozillanickname" ), addr.nickName() );
 
   ldif_out( t, QLatin1String( "mail" ), addr.preferredEmail() );
-  if ( addr.emails().count() > 1 ) {
-    ldif_out( t, QLatin1String( "mozillasecondemail" ), addr.emails()[ 1 ] );
+  for (int i = 1; i < addr.emails().count(); ++i) {
+      if (i == 0) {
+          //nothing
+      } else if (i == 1) {
+          ldif_out( t, QLatin1String( "mozillasecondemail" ), addr.emails()[ 1 ] );
+      } else {
+          ldif_out( t, QLatin1String( "othermailbox" ), addr.emails()[ i ] );
+      }
   }
 //ldif_out( t, "mozilla_AIMScreenName: %1\n", "screen_name" );
 
@@ -125,10 +178,10 @@ bool LDIFConverter::addresseeToLDIF( const Addressee &addr, QString &str )
   QStringList streets = homeAddr.street().split( QLatin1Char( '\n' ) );
   const int numberOfStreets( streets.count() );
   if ( numberOfStreets > 0 ) {
-    ldif_out( t, QLatin1String( "homepostaladdress" ), streets[ 0 ] ); // Netscape 7
+    ldif_out( t, QLatin1String( "homepostaladdress" ), streets.at(0) ); // Netscape 7
   }
   if ( numberOfStreets > 1 ) {
-    ldif_out( t, QLatin1String( "mozillahomepostaladdress2" ), streets[ 1 ] ); // Netscape 7
+    ldif_out( t, QLatin1String( "mozillahomepostaladdress2" ), streets.at(1) ); // Netscape 7
   }
   ldif_out( t, QLatin1String( "mozillahomelocalityname" ), homeAddr.locality() ); // Netscape 7
   ldif_out( t, QLatin1String( "mozillahomestate" ), homeAddr.region() );
@@ -140,10 +193,10 @@ bool LDIFConverter::addresseeToLDIF( const Addressee &addr, QString &str )
 
   streets = workAddr.street().split( QLatin1Char( '\n' ) );
   if ( streets.count() > 0 ) {
-    ldif_out( t, QLatin1String( "postaladdress" ), streets[ 0 ] );
+    ldif_out( t, QLatin1String( "street" ), streets.at(0) );
   }
   if ( streets.count() > 1 ) {
-    ldif_out( t, QLatin1String( "mozillapostaladdress2" ), streets[ 1 ] );
+    ldif_out( t, QLatin1String( "mozillaworkstreet2" ), streets.at(1) );
   }
   ldif_out( t, QLatin1String( "countryname" ), Address::ISOtoCountry( workAddr.country() ) );
   ldif_out( t, QLatin1String( "l" ), workAddr.locality() );
@@ -175,17 +228,13 @@ bool LDIFConverter::addresseeToLDIF( const Addressee &addr, QString &str )
   }
 
   const QDateTime birthday = addr.birthday();
-  if ( birthday.isValid() ) {
+  if ( birthday.date().isValid() ) {
     const QDate date = birthday.date();
     ldif_out( t, QLatin1String( "birthyear" ), QString::number( date.year() ) );
     ldif_out( t, QLatin1String( "birthmonth" ), QString::number( date.month() ) );
     ldif_out( t, QLatin1String( "birthday" ), QString::number( date.day() ) );
   }
 
-  t << "objectclass: top\n";
-  t << "objectclass: person\n";
-  t << "objectclass: organizationalPerson\n";
-
   t << "\n";
 
   return true;
@@ -193,87 +242,99 @@ bool LDIFConverter::addresseeToLDIF( const Addressee &addr, QString &str )
 
 /* convert from LDIF stream */
 
+bool LDIFConverter::LDIFToAddressee( const QString &str, AddresseeList &addrList, ContactGroup::List &contactGroupList,
+                                  const QDateTime &dt )
+{
+    if ( str.isEmpty() ) {
+      return true;
+    }
+    bool endldif = false, end = false;
+    Ldif ldif;
+    Ldif::ParseValue ret;
+    Addressee a;
+    ContactGroup contactGroup;
+    Address homeAddr, workAddr;
+    int birthday = -1;
+    int birthmonth = -1;
+    int birthyear = -1;
+
+    ldif.setLdif( str.toLatin1() );
+    QDateTime qdt = dt;
+    if ( !qdt.isValid() ) {
+      qdt = QDateTime::currentDateTime();
+    }
+    a.setRevision( qdt );
+    homeAddr = Address( Address::Home );
+    workAddr = Address( Address::Work );
+
+    do {
+      ret = ldif.nextItem();
+      switch ( ret ) {
+        case Ldif::Item:
+        {
+          QString fieldname = ldif.attr().toLower();
+          QString value = QString::fromUtf8( ldif.value(), ldif.value().size() );
+          evaluatePair( a, homeAddr, workAddr, fieldname, value, birthday, birthmonth, birthyear, contactGroup );
+          break;
+        }
+        case Ldif::EndEntry:
+        {
+          if (contactGroup.count() == 0) {
+              // if the new address is not empty, append it
+              QDateTime birthDate( QDate( birthyear, birthmonth, birthday ) );
+              if ( birthDate.isValid() ) {
+                  a.setBirthday( birthDate );
+              }
+
+              if ( !a.formattedName().isEmpty() || !a.name().isEmpty() ||
+                   !a.familyName().isEmpty() ) {
+                  if ( !homeAddr.isEmpty() ) {
+                      a.insertAddress( homeAddr );
+                  }
+                  if ( !workAddr.isEmpty() ) {
+                      a.insertAddress( workAddr );
+                  }
+                  addrList.append( a );
+              }
+          } else {
+              contactGroupList.append(contactGroup);
+          }
+          a = Addressee();
+          contactGroup = ContactGroup();
+          a.setRevision( qdt );
+          homeAddr = Address( Address::Home );
+          workAddr = Address( Address::Work );
+        }
+        break;
+        case Ldif::MoreData:
+        {
+          if ( endldif ) {
+            end = true;
+          } else {
+            ldif.endLdif();
+            endldif = true;
+            break;
+          }
+        }
+        default:
+          break;
+      }
+    } while ( !end );
+    return true;
+}
+
+
 bool LDIFConverter::LDIFToAddressee( const QString &str, AddresseeList &addrList,
                                      const QDateTime &dt )
 {
-  if ( str.isEmpty() ) {
-    return true;
-  }
-
-  bool endldif = false, end = false;
-  Ldif ldif;
-  Ldif::ParseValue ret;
-  Addressee a;
-  Address homeAddr, workAddr;
-  int birthday = -1;
-  int birthmonth = -1;
-  int birthyear = -1;
-
-  ldif.setLdif( str.toLatin1() );
-  QDateTime qdt = dt;
-  if ( !qdt.isValid() ) {
-    qdt = QDateTime::currentDateTime();
-  }
-  a.setRevision( qdt );
-  homeAddr = Address( Address::Home );
-  workAddr = Address( Address::Work );
-
-  do {
-    ret = ldif.nextItem();
-    switch ( ret ) {
-      case Ldif::Item:
-      {
-        QString fieldname = ldif.attr().toLower();
-        QString value = QString::fromUtf8( ldif.value(), ldif.value().size() );
-        evaluatePair( a, homeAddr, workAddr, fieldname, value, birthday, birthmonth, birthyear );
-        break;
-      }
-      case Ldif::EndEntry:
-      {
-        // if the new address is not empty, append it
-        QDateTime birthDate( QDate( birthyear, birthmonth, birthday ) );
-        if ( birthDate.isValid() ) {
-          a.setBirthday( birthDate );
-        }
-
-        if ( !a.formattedName().isEmpty() || !a.name().isEmpty() ||
-             !a.familyName().isEmpty() ) {
-          if ( !homeAddr.isEmpty() ) {
-            a.insertAddress( homeAddr );
-          }
-          if ( !workAddr.isEmpty() ) {
-            a.insertAddress( workAddr );
-          }
-          addrList.append( a );
-        }
-        a = Addressee();
-        a.setRevision( qdt );
-        homeAddr = Address( Address::Home );
-        workAddr = Address( Address::Work );
-      }
-      break;
-      case Ldif::MoreData:
-      {
-        if ( endldif ) {
-          end = true;
-        } else {
-          ldif.endLdif();
-          endldif = true;
-          break;
-        }
-      }
-      default:
-        break;
-    }
-  } while ( !end );
-
-  return true;
+    ContactGroup::List contactGroupList;
+    return LDIFToAddressee( str, addrList, contactGroupList, dt);
 }
 
 bool LDIFConverter::evaluatePair( Addressee &a, Address &homeAddr,
                                   Address &workAddr,
                                   QString &fieldname, QString &value,
-                                  int &birthday, int &birthmonth, int &birthyear )
+                                  int &birthday, int &birthmonth, int &birthyear, ContactGroup &contactGroup )
 {
   if ( fieldname == QLatin1String( "dn" ) ) { // ignore & return false!
     return false;
@@ -312,7 +373,8 @@ bool LDIFConverter::evaluatePair( Addressee &a, Address &homeAddr,
     return true;
   }
   if ( fieldname == QLatin1String( "mail" ) ||
-       fieldname == QLatin1String( "mozillasecondemail" ) ) { // mozilla
+       fieldname == QLatin1String( "mozillasecondemail" ) /* mozilla */ ||
+       fieldname == QLatin1String( "othermailbox" ) /*TheBat!*/)  {
     if ( a.emails().indexOf( value ) == -1 ) {
       a.insertEmail( value );
     }
@@ -341,20 +403,20 @@ bool LDIFConverter::evaluatePair( Addressee &a, Address &homeAddr,
     return true;
   }
 
-  if ( fieldname == QLatin1String( "description" ) ) {
-addComment:
-    if ( !a.note().isEmpty() ) {
-      a.setNote( a.note() + QLatin1Char( '\n' ) );
-    }
-    a.setNote( a.note() + value );
-    return true;
-  }
-
-  if ( fieldname == QLatin1String( "custom1" ) ||
+  if ( fieldname == QLatin1String( "description" ) ||
+       fieldname == QLatin1String( "mozillacustom1" ) ||
+       fieldname == QLatin1String( "mozillacustom2" ) ||
+       fieldname == QLatin1String( "mozillacustom3" ) ||
+       fieldname == QLatin1String( "mozillacustom4" ) ||
+       fieldname == QLatin1String( "custom1" ) ||
        fieldname == QLatin1String( "custom2" ) ||
        fieldname == QLatin1String( "custom3" ) ||
        fieldname == QLatin1String( "custom4" ) ) {
-    goto addComment;
+      if ( !a.note().isEmpty() ) {
+        a.setNote( a.note() + QLatin1Char( '\n' ) );
+      }
+      a.setNote( a.note() + value );
+      return true;
   }
 
   if ( fieldname == QLatin1String( "homeurl" ) ||
@@ -381,12 +443,8 @@ addComment:
     return true;
   }
 
-  if ( fieldname == QLatin1String( "mobile" ) ) {         // mozilla/Netscape 7
-    a.insertPhoneNumber( PhoneNumber( value, PhoneNumber::Cell ) );
-    return true;
-  }
-
-  if ( fieldname == QLatin1String( "cellphone" ) ) {
+  if ( fieldname == QLatin1String( "mobile" ) || /* mozilla/Netscape 7 */
+       fieldname == QLatin1String( "cellphone" )) {
     a.insertPhoneNumber( PhoneNumber( value, PhoneNumber::Cell ) );
     return true;
   }
@@ -419,7 +477,8 @@ addComment:
     return true;
   }
 
-  if ( fieldname == QLatin1String( "mozillapostaladdress2" ) ) {  // mozilla
+  if ( fieldname == QLatin1String( "mozillapostaladdress2" ) ||
+       fieldname == QLatin1String( "mozillaworkstreet2" ) ) {  // mozilla
     workAddr.setStreet( workAddr.street() + QLatin1String( "\n" ) + value );
     return true;
   }
@@ -511,8 +570,9 @@ addComment:
     QStringList list = value.split( QLatin1Char( ',' ) );
     QString name, email;
 
-    QStringList::Iterator it;
-    for ( it = list.begin(); it != list.end(); ++it ) {
+    QStringList::ConstIterator it;
+    QStringList::ConstIterator end(list.constEnd());
+    for ( it = list.constBegin(); it != end; ++it ) {
       if ( ( *it ).startsWith( QLatin1String( "cn=" ) ) ) {
         name = ( *it ).mid( 3 ).trimmed();
       }
@@ -523,8 +583,10 @@ addComment:
     if ( !name.isEmpty() && !email.isEmpty() ) {
       email = QLatin1String( " <" ) + email + QLatin1Char( '>' );
     }
-    a.insertEmail( name + email );
-    a.insertCategory( i18n( "List of Emails" ) );
+    ContactGroup::Data data;
+    data.setEmail(email);
+    data.setName(name);
+    contactGroup.append(data);
     return true;
   }
 
@@ -539,6 +601,11 @@ addComment:
     }
   }
 
+  if ( fieldname == QLatin1String( "display-name" ) ) {
+      contactGroup.setName(value);
+    return true;
+  }
+
   if ( fieldname == QLatin1String( "objectclass" ) ) { // ignore
     return true;
   }
@@ -555,6 +622,13 @@ addComment:
     birthday = value.toInt();
     return true;
   }
+  if ( fieldname == QLatin1String("xbatbirthday")) {
+    const QDate dt = QDate::fromString(value, QString::fromLatin1("yyyyMMdd"));
+    if (dt.isValid()) {
+        a.setBirthday(QDateTime(dt));
+    }
+    return true;
+  }
 
   kWarning( 5700 ) << QString::fromLatin1( "LDIFConverter: Unknown field for '%1': '%2=%3'\n" ).
     arg( a.formattedName() ).arg( fieldname ).arg( value );
