@@ -647,7 +647,7 @@ icalproperty *ICalFormatImpl::writeOrganizer( const Person &organizer )
     return 0;
   }
 
-  icalproperty *p = icalproperty_new_organizer( "MAILTO:" + organizer.email().toUtf8() );
+  icalproperty *p = icalproperty_new_organizer( QByteArray(QByteArray("MAILTO:") + organizer.email().toUtf8()) );
 
   if ( !organizer.name().isEmpty() ) {
     icalproperty_add_parameter(
@@ -692,7 +692,7 @@ icalproperty *ICalFormatImpl::writeAttendee( Attendee *attendee )
   }
 
   icalproperty *p =
-    icalproperty_new_attendee( "mailto:" + attendee->email().toUtf8() );
+    icalproperty_new_attendee( QByteArray(QByteArray("mailto:") + attendee->email().toUtf8()) );
 
   if ( !attendee->name().isEmpty() ) {
     icalproperty_add_parameter(
@@ -984,7 +984,7 @@ icalcomponent *ICalFormatImpl::writeAlarm( Alarm *alarm )
     for ( QList<Person>::ConstIterator ad = addresses.constBegin();
           ad != addresses.constEnd();  ++ad ) {
       if ( !(*ad).email().isEmpty() ) {
-        icalproperty *p = icalproperty_new_attendee( "MAILTO:" + (*ad).email().toUtf8() );
+        icalproperty *p = icalproperty_new_attendee( QByteArray(QByteArray("MAILTO:") + (*ad).email().toUtf8()) );
         if ( !(*ad).name().isEmpty() ) {
           icalproperty_add_parameter(
             p, icalparameter_new_cn( quoteForParam( (*ad).name() ).toUtf8() ) );
