@@ -36,6 +36,8 @@
 
 #include <KDebug>
 #include <QDate>
+#include <QDataStream>
+#include <KDateTime>
 
 using namespace KCalCore;
 
@@ -57,7 +59,7 @@ public:
 
     MemoryCalendar *q;
     CalFormat *mFormat;                    // calendar format
-    QString mIncidenceBeingUpdated;        //  Instance identifier of Incidence currently beeing updated
+    QString mIncidenceBeingUpdated;        //  Instance identifier of Incidence currently being updated
 
     /**
      * List of all incidences.
