@@ -86,29 +86,29 @@ class RecurrenceRule;
 */
 class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
 {
-  public:
+public:
     class RecurrenceObserver
     {
-      public:
+    public:
         virtual ~RecurrenceObserver();
         /** This method will be called on each change of the recurrence object */
-        virtual void recurrenceUpdated( Recurrence *r ) = 0;
+        virtual void recurrenceUpdated(Recurrence *r) = 0;
     };
 
     /** enumeration for describing how an event recurs, if at all. */
     enum {
-      rNone = 0,
-      rMinutely = 0x001,
-      rHourly = 0x0002,
-      rDaily = 0x0003,
-      rWeekly = 0x0004,
-      rMonthlyPos = 0x0005,
-      rMonthlyDay = 0x0006,
-      rYearlyMonth = 0x0007,
-      rYearlyDay = 0x0008,
-      rYearlyPos = 0x0009,
-      rOther = 0x000A,
-      rMax=0x00FF
+        rNone = 0,
+        rMinutely = 0x001,
+        rHourly = 0x0002,
+        rDaily = 0x0003,
+        rWeekly = 0x0004,
+        rMonthlyPos = 0x0005,
+        rMonthlyDay = 0x0006,
+        rYearlyMonth = 0x0007,
+        rYearlyDay = 0x0008,
+        rYearlyPos = 0x0009,
+        rOther = 0x000A,
+        rMax=0x00FF
     };
 
     /**
@@ -120,7 +120,7 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
       Copy constructor.
       @param r instance to copy from
     */
-    Recurrence( const Recurrence &r );
+    Recurrence(const Recurrence &r);
 
     /**
       Destructor.
@@ -132,20 +132,22 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
       @param r instance to compare with
       @return true if recurrences are the same, false otherwise
     */
-    bool operator==( const Recurrence &r ) const;
+    bool operator==(const Recurrence &r) const;
 
     /**
       Comparison operator for inequality.
       @param r instance to compare with
       @return true if recurrences are the different, false if the same
     */
-    bool operator!=( const Recurrence &r ) const  { return !operator==(r); }
+    bool operator!=(const Recurrence &r) const  {
+        return !operator==(r);
+    }
 
     /**
       Assignment operator.
       @param r the recurrence which will be assigned to this.
     */
-    Recurrence &operator=( const Recurrence &r );
+    Recurrence &operator=(const Recurrence &r);
 
     /** Return the start date/time of the recurrence (Time for all-day recurrences will be 0:00).
      @return the current start/time of the recurrence. */
@@ -157,7 +159,7 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
        start is set to a date and time, and the recurrence is set to non-all-day.
        @param start the new start date or date/time of the recurrence.
     */
-    void setStartDateTime( const KDateTime &start );
+    void setStartDateTime(const KDateTime &start);
 
     /** Set whether the recurrence has no time, just a date.
      * All-day means -- according to rfc2445 -- that the event has no time
@@ -169,10 +171,10 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
     /** Sets whether the dtstart is a all-day (i.e. has no time attached)
        @param allDay If the recurrence is for all-day item (true) or has a time associated (false).
        */
-    void setAllDay( bool allDay );
+    void setAllDay(bool allDay);
 
     /** Set if recurrence is read-only or can be changed. */
-    void setRecurReadOnly( bool readOnly );
+    void setRecurReadOnly(bool readOnly);
 
     /** Returns true if the recurrence is read-only, or false if it can be changed. */
     bool recurReadOnly() const;
@@ -189,7 +191,7 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
      *
      * @param rrule the recurrence rule to get the type for
      */
-    static ushort recurrenceType( const RecurrenceRule *rrule );
+    static ushort recurrenceType(const RecurrenceRule *rrule);
 
     /**
       Returns true if the date specified is one on which the event will recur.
@@ -197,7 +199,7 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
       @param date date to check.
       @param timeSpec time specification for @p date.
     */
-    bool recursOn( const QDate &date, const KDateTime::Spec &timeSpec ) const;
+    bool recursOn(const QDate &date, const KDateTime::Spec &timeSpec) const;
 
     /**
       Returns true if the date/time specified is one at which the event will
@@ -206,7 +208,7 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
 
       @param dt is the date/time to check.
     */
-    bool recursAt( const KDateTime &dt ) const;
+    bool recursAt(const KDateTime &dt) const;
 
     /**
       Removes all recurrence rules. Recurrence dates and exceptions are
@@ -225,7 +227,7 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
      * @param date the date for which to find the recurrence times
      * @param timeSpec time specification for @p date
      */
-    TimeList recurTimesOn( const QDate &date, const KDateTime::Spec &timeSpec ) const;
+    TimeList recurTimesOn(const QDate &date, const KDateTime::Spec &timeSpec) const;
 
     /** Returns a list of all the times at which the recurrence will occur
      * between two specified times.
@@ -239,7 +241,7 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
      * @param end inclusive end of interval
      * @return list of date/time values
      */
-    DateTimeList timesInInterval( const KDateTime &start, const KDateTime &end ) const;
+    DateTimeList timesInInterval(const KDateTime &start, const KDateTime &end) const;
 
     /** Returns the date and time of the next recurrence, after the specified date/time.
      * If the recurrence has no time, the next date after the specified date is returned.
@@ -247,7 +249,7 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
      * @return date/time of next recurrence (strictly later than the given
      *         KDateTime), or invalid date if none.
      */
-    KDateTime getNextDateTime( const KDateTime &preDateTime ) const;
+    KDateTime getNextDateTime(const KDateTime &preDateTime) const;
 
     /** Returns the date and time of the last previous recurrence, before the specified date/time.
      * If a time later than 00:00:00 is specified and the recurrence has no time, 00:00:00 on
@@ -257,13 +259,13 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
      * @return date/time of previous recurrence (strictly earlier than the given
      *         KDateTime), or invalid date if none.
      */
-    KDateTime getPreviousDateTime( const KDateTime &afterDateTime ) const;
+    KDateTime getPreviousDateTime(const KDateTime &afterDateTime) const;
 
     /** Returns frequency of recurrence, in terms of the recurrence time period type. */
     int frequency() const;
 
     /** Sets the frequency of recurrence, in terms of the recurrence time period type. */
-    void setFrequency( int freq );
+    void setFrequency(int freq);
 
     /**
      * Returns -1 if the event recurs infinitely, 0 if the end date is set,
@@ -273,17 +275,17 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
 
     /** Sets the total number of times the event is to occur, including both the
      * first and last. */
-    void setDuration( int duration );
+    void setDuration(int duration);
 
     /** Returns the number of recurrences up to and including the date/time specified.
      *  @warning This function can be very time consuming - use it sparingly!
      */
-    int durationTo( const KDateTime &dt ) const;
+    int durationTo(const KDateTime &dt) const;
 
     /** Returns the number of recurrences up to and including the date specified.
      *  @warning This function can be very time consuming - use it sparingly!
      */
-    int durationTo( const QDate &date ) const;
+    int durationTo(const QDate &date) const;
 
     /** Returns the date/time of the last recurrence.
      * An invalid date is returned if the recurrence has no end.
@@ -298,11 +300,11 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
     /** Sets the date of the last recurrence. The end time is set to the recurrence start time.
      * @param endDate the ending date after which to stop recurring. If the
      *   recurrence is not all-day, the end time will be 23:59.*/
-    void setEndDate( const QDate &endDate );
+    void setEndDate(const QDate &endDate);
 
     /** Sets the date and time of the last recurrence.
      * @param endDateTime the ending date/time after which to stop recurring. */
-    void setEndDateTime( const KDateTime &endDateTime );
+    void setEndDateTime(const KDateTime &endDateTime);
 
     /**
       Shift the times of the recurrence so that they appear at the same clock
@@ -318,7 +320,7 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
       @param oldSpec the time specification which provides the clock times
       @param newSpec the new time specification
     */
-    void shiftTimes( const KDateTime::Spec &oldSpec, const KDateTime::Spec &newSpec );
+    void shiftTimes(const KDateTime::Spec &oldSpec, const KDateTime::Spec &newSpec);
 
     /** Sets an event to recur minutely. By default infinite recurrence is used.
         To set an end date use the method setEndDate and to set the number
@@ -330,7 +332,7 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
         modified.
      * @param freq the frequency to recur, e.g. 2 is every other minute
      */
-    void setMinutely( int freq );
+    void setMinutely(int freq);
 
     /** Sets an event to recur hourly. By default infinite recurrence is used.
         The minute of the recurrence is taken from the start date (if you
@@ -345,7 +347,7 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
         modified.
      * @param freq the frequency to recur, e.g. 2 is every other hour
      */
-    void setHourly( int freq );
+    void setHourly(int freq);
 
     /** Sets an event to recur daily. By default infinite recurrence is used.
         The minute and second of the recurrence is taken from the start date
@@ -360,7 +362,7 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
         modified.
      * @param freq the frequency to recur, e.g. 2 is every other day
      */
-    void setDaily( int freq );
+    void setDaily(int freq);
 
     /** Sets an event to recur weekly. By default infinite recurrence is used.
         To set an end date use the method setEndDate and to set the number
@@ -373,7 +375,7 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
      * @param freq the frequency to recur, e.g. every other week etc.
      * @param weekStart the first day of the week (Monday=1 .. Sunday=7, default is Monday).
      */
-    void setWeekly( int freq, int weekStart = 1 );
+    void setWeekly(int freq, int weekStart = 1);
     /** Sets an event to recur weekly. By default infinite recurrence is used.
         To set an end date use the method setEndDate and to set the number
         of occurrences use setDuration.
@@ -386,12 +388,12 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
      * @param days a 7 bit array indicating which days on which to recur (bit 0 = Monday).
      * @param weekStart the first day of the week (Monday=1 .. Sunday=7, default is Monday).
      */
-    void setWeekly( int freq, const QBitArray &days, int weekStart = 1 );
+    void setWeekly(int freq, const QBitArray &days, int weekStart = 1);
 
     /** Adds days to the weekly day recurrence list.
      * @param days a 7 bit array indicating which days on which to recur (bit 0 = Monday).
      */
-    void addWeeklyDays( const QBitArray &days );
+    void addWeeklyDays(const QBitArray &days);
     /** Returns the first day of the week.  Uses only the
      * first RRULE if present (i.e. a second RRULE as well as all EXRULES are
      * ignored!
@@ -416,7 +418,7 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
         modified.
      * @param freq the frequency to recur, e.g. 3 for every third month.
      */
-    void setMonthly( int freq );
+    void setMonthly(int freq);
 
     /** Adds a position (e.g. first monday) to the monthly recurrence rule.
      * @param pos the position in the month for the recurrence, with valid
@@ -425,14 +427,14 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
      * Example: pos = 2, and bits 0 and 2 are set in days:
      * the rule is to repeat every 2nd Monday and Wednesday in the month.
      */
-    void addMonthlyPos( short pos, const QBitArray &days );
-    void addMonthlyPos( short pos, ushort day );
+    void addMonthlyPos(short pos, const QBitArray &days);
+    void addMonthlyPos(short pos, ushort day);
 
     /** Adds a date (e.g. the 15th of each month) to the monthly day
      *  recurrence list.
      * @param day the date in the month to recur.
      */
-    void addMonthlyDate( short day );
+    void addMonthlyDate(short day);
 
     /** Returns list of day positions in months. */
     QList<RecurrenceRule::WDayPos> monthPositions() const;
@@ -463,7 +465,7 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
         modified.
      * @param freq the frequency to recur, e.g. 3 for every third year.
      */
-    void setYearly( int freq );
+    void setYearly(int freq);
 
     /** Adds day number of year within a yearly recurrence.
      *  By default infinite recurrence is used. To set an end date use the
@@ -471,7 +473,7 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
      * @param day the day of the year for the event. E.g. if day is 60, this
      *            means Feb 29 in leap years and March 1 in non-leap years.
      */
-    void addYearlyDay( int day );
+    void addYearlyDay(int day);
 
     /** Adds date within a yearly recurrence. The month(s) for the recurrence
      *  can be specified with addYearlyMonth(), otherwise the month of the
@@ -481,14 +483,14 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
      *   method setEndDate and to set the number of occurrences use setDuration.
      * @param date the day of the month for the event
      */
-    void addYearlyDate( int date );
+    void addYearlyDate(int date);
 
     /** Adds month in yearly recurrence. You can specify specific day numbers
      *  within the months (by calling addYearlyDate()) or specific day positions
      *  within the month (by calling addYearlyPos).
      * @param _rNum the month in which the event shall recur.
      */
-    void addYearlyMonth( short _rNum );
+    void addYearlyMonth(short _rNum);
 
     /** Adds position within month/year within a yearly recurrence. If months
      *  are specified (via addYearlyMonth()), the parameters are understood as
@@ -506,7 +508,7 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
      *   If no months are specified, the fule is to repeat every year on the
      *   2nd Monday and Wednesday of the year.
      */
-    void addYearlyPos( short pos, const QBitArray &days );
+    void addYearlyPos(short pos, const QBitArray &days);
 
     /** Returns the day numbers within a yearly recurrence.
      * @return the days of the year for the event. E.g. if the list contains
@@ -559,7 +561,7 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
       Add a recurrence rule to the recurrence.
       @param rrule the recurrence rule to add
      */
-    void addRRule( RecurrenceRule *rrule );
+    void addRRule(RecurrenceRule *rrule);
 
     /**
       Remove a recurrence rule from the recurrence.
@@ -567,13 +569,13 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
       to ensure that it is deleted.
       @param rrule the recurrence rule to remove
      */
-    void removeRRule( RecurrenceRule *rrule );
+    void removeRRule(RecurrenceRule *rrule);
 
     /**
       Remove a recurrence rule from the recurrence and delete it.
       @param rrule the recurrence rule to remove
      */
-    void deleteRRule( RecurrenceRule *rrule );
+    void deleteRRule(RecurrenceRule *rrule);
 
     // EXRULE
     RecurrenceRule::List exRules() const;
@@ -582,7 +584,7 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
       Add an exception rule to the recurrence.
       @param exrule the exception rule to add
      */
-    void addExRule( RecurrenceRule *exrule );
+    void addExRule(RecurrenceRule *exrule);
 
     /**
       Remove an exception rule from the recurrence.
@@ -590,31 +592,31 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
       to ensure that it is deleted.
       @param exrule the exception rule to remove
      */
-    void removeExRule( RecurrenceRule *exrule );
+    void removeExRule(RecurrenceRule *exrule);
 
     /**
       Remove an exception rule from the recurrence and delete it.
       @param exrule the exception rule to remove
      */
-    void deleteExRule( RecurrenceRule *exrule );
+    void deleteExRule(RecurrenceRule *exrule);
 
     // RDATE
     DateTimeList rDateTimes() const;
     DateList rDates() const;
-    void setRDateTimes( const DateTimeList &rdates );
-    void setRDates( const DateList &rdates );
-    void addRDateTime( const KDateTime &rdate );
-    void addRDate( const QDate &rdate );
+    void setRDateTimes(const DateTimeList &rdates);
+    void setRDates(const DateList &rdates);
+    void addRDateTime(const KDateTime &rdate);
+    void addRDate(const QDate &rdate);
 
     // ExDATE
     DateTimeList exDateTimes() const;
     DateList exDates() const;
-    void setExDateTimes( const DateTimeList &exdates );
-    void setExDates( const DateList &exdates );
-    void addExDateTime( const KDateTime &exdate );
-    void addExDate( const QDate &exdate );
+    void setExDateTimes(const DateTimeList &exdates);
+    void setExDates(const DateList &exdates);
+    void addExDateTime(const KDateTime &exdate);
+    void addExDate(const QDate &exdate);
 
-    RecurrenceRule *defaultRRule( bool create = false ) const;
+    RecurrenceRule *defaultRRule(bool create = false) const;
     RecurrenceRule *defaultRRuleConst() const;
     void updated();
 
@@ -625,36 +627,36 @@ class KCALCORE_EXPORT Recurrence : public RecurrenceRule::RuleObserver
       @param observer the Recurrence::Observer-derived object, which
       will be installed as an observer of this object.
     */
-    void addObserver( RecurrenceObserver *observer );
+    void addObserver(RecurrenceObserver *observer);
     /**
       Removes an observer that was added with addObserver. If the
       given object was not an observer, it does nothing.
       @param observer the Recurrence::Observer-derived object to
       be removed from the list of observers of this object.
     */
-    void removeObserver( RecurrenceObserver *observer );
+    void removeObserver(RecurrenceObserver *observer);
 
-    void recurrenceChanged( RecurrenceRule * );
+    void recurrenceChanged(RecurrenceRule *);
 
-  protected:
-    RecurrenceRule *setNewRecurrenceType( RecurrenceRule::PeriodType type, int freq );
+protected:
+    RecurrenceRule *setNewRecurrenceType(RecurrenceRule::PeriodType type, int freq);
 
-  private:
+private:
     //@cond PRIVATE
     class Private;
     Private *const d;
     //@endcond
 
-    friend KCALCORE_EXPORT QDataStream& operator<<( QDataStream &out, KCalCore::Recurrence * );
-    friend KCALCORE_EXPORT QDataStream& operator>>( QDataStream &in, KCalCore::Recurrence * );
+    friend KCALCORE_EXPORT QDataStream& operator<<(QDataStream &out, KCalCore::Recurrence *);
+    friend KCALCORE_EXPORT QDataStream& operator>>(QDataStream &in, KCalCore::Recurrence *);
 };
 
 /**
  * Recurrence serializer and deserializer.
  * @since 4.12
  */
-KCALCORE_EXPORT QDataStream& operator<<( QDataStream &out, KCalCore::Recurrence * );
-KCALCORE_EXPORT QDataStream& operator>>( QDataStream &in, KCalCore::Recurrence * );
+KCALCORE_EXPORT QDataStream& operator<<(QDataStream &out, KCalCore::Recurrence *);
+KCALCORE_EXPORT QDataStream& operator>>(QDataStream &in, KCalCore::Recurrence *);
 
 }
 
