@@ -19,7 +19,7 @@
 
 #include "closejob.h"
 
-#include <KDE/KLocale>
+#include <KDE/KLocalizedString>
 
 #include "job_p.h"
 #include "message_p.h"
@@ -51,4 +51,3 @@ void CloseJob::doStart()
   Q_D( CloseJob );
   d->tags << d->sessionInternal()->sendCommand( "CLOSE" );
 }
-
