@@ -22,7 +22,7 @@
 #include "message_p.h"
 #include "session_p.h"
 
-#include <KDE/KLocale>
+#include <KDE/KLocalizedString>
 #include <KDE/KDebug>
 
 using namespace KIMAP;
@@ -49,7 +49,6 @@ QuotaJobBase::QuotaJobBase( Session *session )
 {
 }
 
-
 QuotaJobBase::QuotaJobBase( JobPrivate &dd )
   : Job( dd )
 {
@@ -82,4 +81,3 @@ qint64 QuotaJobBase::limit(const QByteArray& resource)
   }
   return -1;
 }
-
