@@ -22,6 +22,8 @@
 #include <kcomponentdata.h>
 #include <kaboutdata.h>
 #include <kdebug.h>
+#include <klocale.h>
+#include <klocalizedstring.h>
 #include <qtcpsocket.h>
 #include <QCoreApplication>
 #include <qsignalspy.h>
