@@ -26,7 +26,7 @@ class IdentityTester : public QObject
 {
   Q_OBJECT
 
-private slots:
+private Q_SLOTS:
   void test_NullIdentity();
   void test_Aliases();
 };
